<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko" sourcelanguage="en">
<context>
    <name>ArrowToolOptionsBox</name>
    <message>
        <source>Z:</source>
        <translation></translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>이동:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation></translation>
    </message>
    <message>
        <source>SO:</source>
        <translation></translation>
    </message>
    <message>
        <source>Rotation:</source>
        <translation>회전:</translation>
    </message>
    <message>
        <source>Global:</source>
        <translation>전체:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>수평:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>수직:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>이동</translation>
    </message>
    <message>
        <source>(</source>
        <translation></translation>
    </message>
    <message>
        <source>)</source>
        <translation></translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>회전</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
    <message>
        <source>Maintain:</source>
        <translation>유지:</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>왜곡</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>중심위치</translation>
    </message>
    <message>
        <source>Table</source>
        <translation>테이블</translation>
    </message>
    <message>
        <source>Pick:</source>
        <translation>선택:</translation>
    </message>
</context>
<context>
    <name>BrushTool</name>
    <message>
        <source>Size</source>
        <translation type="vanished">크기</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="vanished">정확도:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="vanished">부드러운:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="vanished">사전설정:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;사용자 정의&gt;</translation>
    </message>
    <message>
        <source>Break</source>
        <translation type="vanished">분리</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="vanished">압력</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="vanished">캡</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="vanished">결합</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="vanished">마이터:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">범위:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="vanished">스냅</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="vanished">끄기</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="vanished">선형</translation>
    </message>
    <message>
        <source>In</source>
        <translation type="vanished">가속</translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="vanished">감속</translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation type="vanished">가속&amp;감속</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">낮은</translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="vanished">중간</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">높은</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="vanished">버트 캡</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="vanished">라운드 캡</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="vanished">돌출선 끝</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="vanished">마이터 결합</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="vanished">라운드 결합</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="vanished">베벨 결합</translation>
    </message>
</context>
<context>
    <name>BrushToolOptionsBox</name>
    <message>
        <source>Preset Name</source>
        <translation>사전설정 이름</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>ControlPointEditorTool</name>
    <message>
        <source>Auto Select Drawing</source>
        <translation>자동 그리기 선택</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>스냅</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>올가미</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>낮은</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>중간</translation>
    </message>
    <message>
        <source>High</source>
        <translation>높은</translation>
    </message>
</context>
<context>
    <name>ControlPointSelection</name>
    <message>
        <source>Set Linear Control Point</source>
        <translation>선형 제어지점 설정</translation>
    </message>
    <message>
        <source>Set Nonlinear Control Point</source>
        <translation>비선형 제어 설정</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation>현재</translation>
    </message>
</context>
<context>
    <name>EditTool</name>
    <message>
        <source>Scale Constraint:</source>
        <translation>확대및 축소 설정:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>A/R</source>
        <translation></translation>
    </message>
    <message>
        <source>Mass</source>
        <translation>질량</translation>
    </message>
    <message>
        <source>Auto Select Column</source>
        <translation>열 자동선택</translation>
    </message>
    <message>
        <source>Column</source>
        <translation>열</translation>
    </message>
    <message>
        <source>Pegbar</source>
        <translation>페그바</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>글로벌 키</translation>
    </message>
    <message>
        <source>Lock Center X</source>
        <translation>중심점 좌우 잠금</translation>
    </message>
    <message>
        <source>Lock Center Y</source>
        <translation>중심점 위아래 잠금</translation>
    </message>
    <message>
        <source>Lock Position X</source>
        <translation>위치 좌우 잠금</translation>
    </message>
    <message>
        <source>Lock Position Y</source>
        <translation>위치 위아래 잠금</translation>
    </message>
    <message>
        <source>Lock Rotation</source>
        <translation>잠금 회전</translation>
    </message>
    <message>
        <source>Lock Shear H</source>
        <translation>잠금 변형(수평)</translation>
    </message>
    <message>
        <source>Lock Shear V</source>
        <translation>잠금 변형(수직)</translation>
    </message>
    <message>
        <source>Lock Scale H</source>
        <translation>잠금 확대/축소(수평)</translation>
    </message>
    <message>
        <source>Lock Scale V</source>
        <translation>잠금 확대/축소(수직)</translation>
    </message>
    <message>
        <source>Lock Global Scale</source>
        <translation>잠금 확대/축소(전체)</translation>
    </message>
    <message>
        <source>X and Y Positions</source>
        <translation>좌우/상하 위치</translation>
    </message>
    <message>
        <source>Z Position</source>
        <translation>Z위치</translation>
    </message>
    <message>
        <source>SO</source>
        <translation></translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>회전</translation>
    </message>
    <message>
        <source>Global Scale</source>
        <translation>전체 크기조정</translation>
    </message>
    <message>
        <source>Horizontal and Vertical Scale</source>
        <translation>수평 수직스케일</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>왜곡</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>중심위치</translation>
    </message>
    <message>
        <source>Active Axis</source>
        <translation>활성 축</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>이동</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>중심</translation>
    </message>
    <message>
        <source>All</source>
        <translation>전체</translation>
    </message>
</context>
<context>
    <name>EraserTool</name>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>선택</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>반전</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>프레임 범위</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>올가미</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>폴리선</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>경도:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>모드:</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>영역</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>선 &amp; 영역</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>연필 모드</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>세그먼트</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation>선형</translation>
    </message>
    <message>
        <source>Ease In</source>
        <translation>가속</translation>
    </message>
    <message>
        <source>Ease Out</source>
        <translation>감속</translation>
    </message>
    <message>
        <source>Ease In/Out</source>
        <translation>가속/감속</translation>
    </message>
</context>
<context>
    <name>FillTool</name>
    <message>
        <source>Frame Range</source>
        <translation>프레임 범위</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>올가미</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>폴리선</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>선택</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>모드:</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>영역</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>선 &amp; 영역</translation>
    </message>
    <message>
        <source>Onion Skin</source>
        <translation>어니언 스킨</translation>
    </message>
    <message>
        <source>Fill Depth</source>
        <translation>깊이 채우기</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>세그먼트</translation>
    </message>
    <message>
        <source>Maximum Gap</source>
        <translation>최대 간격</translation>
    </message>
    <message>
        <source>Autopaint Lines</source>
        <translation>자동 색칠</translation>
    </message>
</context>
<context>
    <name>FingerTool</name>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>반전</translation>
    </message>
</context>
<context>
    <name>FullColorBrushTool</name>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>압력</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>불투명도</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>경도:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>사전설정:</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>지우개</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>알파 잠금</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;사용자 정의&gt;</translation>
    </message>
</context>
<context>
    <name>FullColorEraserTool</name>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>불투명도:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>경도:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>올가미</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>올가미</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>반전</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>프레임 범위</translation>
    </message>
</context>
<context>
    <name>FullColorFillTool</name>
    <message>
        <source>Fill Depth</source>
        <translation>깊이 채우기</translation>
    </message>
</context>
<context>
    <name>HandToolOptionsBox</name>
    <message>
        <source>Reset Position</source>
        <translation>위치 재설정</translation>
    </message>
</context>
<context>
    <name>HookTool</name>
    <message>
        <source>Snap</source>
        <translation>스냅</translation>
    </message>
</context>
<context>
    <name>MagnetTool</name>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
</context>
<context>
    <name>PaintBrushTool</name>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>모드:</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>영역</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>선 &amp; 영역</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>선택</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>잠금 알파</translation>
    </message>
</context>
<context>
    <name>PinchTool</name>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <source>Corner:</source>
        <translation>모서리:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>메뉴얼</translation>
    </message>
</context>
<context>
    <name>PlasticTool</name>
    <message>
        <source>Swap Edge</source>
        <translation>가장자리 교환</translation>
    </message>
    <message>
        <source>Collapse Edge</source>
        <translation>가장자리 축소</translation>
    </message>
    <message>
        <source>Split Edge</source>
        <translation>가장자리 분할</translation>
    </message>
    <message>
        <source>Cut Mesh</source>
        <translation>메쉬 잘라내기</translation>
    </message>
    <message>
        <source>Delete Vertex</source>
        <translation>꼭지점 삭제</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>키 설정</translation>
    </message>
    <message>
        <source>Set Rest Key</source>
        <translation>나머지 키 설정</translation>
    </message>
    <message>
        <source>Set Global Key</source>
        <translation>글로벌 키 설정</translation>
    </message>
    <message>
        <source>Set Global Rest Key</source>
        <translation>나머지 글로벌 키 설정</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>모드:</translation>
    </message>
    <message>
        <source>Edit Mesh</source>
        <translation>매쉬 편집</translation>
    </message>
    <message>
        <source>Paint Rigid</source>
        <translation>페인트 강체</translation>
    </message>
    <message>
        <source>Build Skeleton</source>
        <translation>골격 만들기</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>애니메이션</translation>
    </message>
    <message>
        <source>Vertex Name:</source>
        <translation>꼭지점 이름</translation>
    </message>
    <message>
        <source>Allow Stretching</source>
        <translation>스트레칭 허용</translation>
    </message>
    <message>
        <source>Snap To Mesh</source>
        <translation>매쉬에 스냅</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
    <message>
        <source>Rigid</source>
        <translation>강체</translation>
    </message>
    <message>
        <source>Flex</source>
        <translation>플렉스</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>글로벌 키</translation>
    </message>
    <message>
        <source>Keep Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Angle Bounds</source>
        <translation>각도 범위설정</translation>
    </message>
    <message>
        <source>A group of skeletons already exists for current column. Replacing it will also substitute any existing vertex animation.

Do you want to continue?</source>
        <translation>기존 정점명은 파기되고 모든 관련 키가 삭제됩니다.

계속하겠습니까?</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Copy Skeleton</source>
        <translation>골격 복사</translation>
    </message>
    <message>
        <source>Paste Skeleton</source>
        <translation>골격 붙여넣기</translation>
    </message>
    <message>
        <source>Show Mesh</source>
        <translation>메쉬 표시</translation>
    </message>
    <message>
        <source>Show Rigidity</source>
        <translation>강성 표시</translation>
    </message>
    <message>
        <source>Show SO</source>
        <translation>스태킹 표시</translation>
    </message>
    <message>
        <source>Show Skeleton Onion Skin</source>
        <translation>골격 어니언 스킨 표시</translation>
    </message>
    <message>
        <source>The previous vertex name will be discarded, and all associated keys will be lost.

Do you want to proceed?</source>
        <translation>이전 정점명은 삭제되며, 관련된 모든 키가 손실됩니다.

계속 하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>PlasticToolOptionsBox</name>
    <message>
        <source>Create Mesh</source>
        <translation>메쉬 작성</translation>
    </message>
    <message>
        <source>Skeleton:</source>
        <translation>골격:</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>각도</translation>
    </message>
    <message>
        <source>SO</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PrimitiveParam</name>
    <message>
        <source>Shape:</source>
        <translation>모양:</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>원형</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>타원형</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>직선</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>폴리선</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>아치형태</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>다각형</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <source>Thickness:</source>
        <translation>굵기:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>불투명도:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>경도:</translation>
    </message>
    <message>
        <source>Polygon Sides:</source>
        <translation>다각형 변의 수:</translation>
    </message>
    <message>
        <source>Auto Group</source>
        <translation>자동 그룹</translation>
    </message>
    <message>
        <source>Auto Fill</source>
        <translation>자동 채우기</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>선택</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>연필 모드</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>캡</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>버트 캡</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>라운드 캡</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>돌출선 끝</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>결합</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>마이터 결합</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>라운드 결합</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>베벨 결합</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>마이터:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>스냅</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>낮은</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>중간</translation>
    </message>
    <message>
        <source>High</source>
        <translation>높은</translation>
    </message>
    <message>
        <source>MultiArc</source>
        <translation>멀티아크</translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation>부드러운</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>회전</translation>
    </message>
</context>
<context>
    <name>PumpTool</name>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>정확도:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The copied selection cannot be pasted in the current drawing.</source>
        <translation>복사된 선택 항목을 현재 도면에 붙여넣을 수 없음.</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <source>Min:</source>
        <translation>최소:</translation>
    </message>
    <message>
        <source>Max:</source>
        <translation>최대:</translation>
    </message>
    <message>
        <source>Set Save Box : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</source>
        <translation>저장 상자설정 : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</translation>
    </message>
    <message>
        <source>Move Center</source>
        <translation>센터 이동</translation>
    </message>
    <message>
        <source>RGB Picker (R%1, G%2, B%3)</source>
        <translation>RGB 피커 (R%1, G%2, B%3)</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>그룹</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>해제</translation>
    </message>
    <message>
        <source> to Front</source>
        <translation>앞으로</translation>
    </message>
    <message>
        <source> to Forward</source>
        <translation>앞으로</translation>
    </message>
    <message>
        <source> to Back</source>
        <translation>뒤로</translation>
    </message>
    <message>
        <source> to Backward</source>
        <translation>뒷면</translation>
    </message>
    <message>
        <source>Move Group</source>
        <translation>그룹 이동</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>네</translation>
    </message>
    <message>
        <source>No</source>
        <translation>아니오</translation>
    </message>
    <message>
        <source>Modify Fx Gadget  </source>
        <translation>Fx 가젯 수정</translation>
    </message>
    <message>
        <source>The current column is locked.</source>
        <translation>현재 열이 잠겨 있다</translation>
    </message>
    <message>
        <source>The current column is hidden.</source>
        <translation>현재 열이 숨겨져 있음.</translation>
    </message>
    <message>
        <source>It is not possible to edit the audio column.</source>
        <translation>오디오 열을 편집할 수 없음.</translation>
    </message>
    <message>
        <source>Note columns can only be edited in the xsheet or timeline.</source>
        <translation>엑스시트 또는 타임라인에서만 편집할 수 있음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Level column.</source>
        <translation>현재 도구는 레벨 열에 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh column.</source>
        <translation>현재 도구를 메쉬 열에 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used in Level Strip mode.</source>
        <translation>현재 도구는 레벨 편집모드에서 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used to edit a motion path.</source>
        <translation>현재 도구는 모션 경로 편집에 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current level is not editable.</source>
        <translation>현재의 레벨은 편집할 수 없음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Vector Level.</source>
        <translation>현재 툴은 벡터 레벨에서 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Toonz Level.</source>
        <translation>현재 툴은 툰즈레벨에서 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Raster Level.</source>
        <translation>현재 도구는 래스터 레벨에서 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh Level.</source>
        <translation>현재 도구는 메쉬 레벨에서 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a mesh-deformed level</source>
        <translation>현재 도구는 메쉬 변형 레벨에 사용할 수 없음.</translation>
    </message>
    <message>
        <source>The current frame is locked: any editing is forbidden.</source>
        <translation>현재 프레임이 잠겨있어 편집 할 수가 없음.</translation>
    </message>
    <message>
        <source>Deform Raster</source>
        <translation>레스터 변형</translation>
    </message>
    <message>
        <source>Transform Raster</source>
        <translation>레스터 변환</translation>
    </message>
    <message>
        <source>%1   Level : %2  Frame : %3</source>
        <translation>%1 레벨 : %2 프레임 : %3</translation>
    </message>
    <message>
        <source>Modify Stroke Tool</source>
        <translation>선 수정도구</translation>
    </message>
    <message>
        <source>Modify Spline</source>
        <translation>스플라인 수정</translation>
    </message>
    <message>
        <source>The selection cannot be updated. It is not editable.</source>
        <translation>선택을 업데이트 할 수 없습니다. 편집 할 수 없습니다.</translation>
    </message>
    <message>
        <source>The selection cannot be deleted. It is not editable.</source>
        <translation>선택항목을 삭제할 수 없습니다. 편집 할 수 없습니다.</translation>
    </message>
    <message>
        <source>The selection cannot be pasted. It is not editable.</source>
        <translation>선택을 붙여 넣을 수 없습니다. 편집 할 수 없습니다.</translation>
    </message>
    <message>
        <source>The selection cannot be grouped. It is not editable.</source>
        <translation>선택 항목을 그룹화할 수 없음. 그것은 편집할 수 없다.</translation>
    </message>
    <message>
        <source>The selection cannot be entered. It is not editable.</source>
        <translation>선택을 입력 할 수 없습니다. 편집 할 수 없습니다.</translation>
    </message>
    <message>
        <source>The selection cannot be ungrouped. It is not editable.</source>
        <translation>선택을 그룹 해제 할 수 없습니다. 편집 할 수 없습니다.</translation>
    </message>
    <message>
        <source>The selection cannot be moved. It is not editable.</source>
        <translation>선택을 이동할 수 없습니다. 편집 할 수 없습니다.</translation>
    </message>
    <message>
        <source>Snap At Intersection</source>
        <translation>교차점에서 스냅</translation>
    </message>
</context>
<context>
    <name>RGBPickerTool</name>
    <message>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>올가미</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>폴리선</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>수동적 선택</translation>
    </message>
</context>
<context>
    <name>RGBPickerToolOptionsBox</name>
    <message>
        <source>Pick Screen</source>
        <translation>화면 선택</translation>
    </message>
</context>
<context>
    <name>RasterSelectionTool</name>
    <message>
        <source>Modify Savebox</source>
        <translation>세이브 박스 편집모드</translation>
    </message>
    <message>
        <source>No Antialiasing</source>
        <translation>앤티 앨리어싱 없음.</translation>
    </message>
</context>
<context>
    <name>RasterTapeTool</name>
    <message>
        <source>current</source>
        <translation>현재</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>올가미</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>폴리선</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation>거리:</translation>
    </message>
    <message>
        <source>Style Index:</source>
        <translation>스타일 인덱스:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>불투명도:</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>프레임 범위</translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation>각도:</translation>
    </message>
</context>
<context>
    <name>RotateTool</name>
    <message>
        <source>Rotate On Camera Center</source>
        <translation>카메라 중심점을 회전(기준)</translation>
    </message>
</context>
<context>
    <name>RotateToolOptionsBox</name>
    <message>
        <source>Reset Rotation</source>
        <translation>회전 재설정</translation>
    </message>
</context>
<context>
    <name>RulerToolOptionsBox</name>
    <message>
        <source>X:</source>
        <comment>ruler tool option</comment>
        <translation>가로좌표:</translation>
    </message>
    <message>
        <source>Y:</source>
        <comment>ruler tool option</comment>
        <translation>세로좌표:</translation>
    </message>
    <message>
        <source>W:</source>
        <comment>ruler tool option</comment>
        <translation>너비:</translation>
    </message>
    <message>
        <source>H:</source>
        <comment>ruler tool option</comment>
        <translation>수평:</translation>
    </message>
    <message>
        <source>A:</source>
        <comment>ruler tool option</comment>
        <translation>각도:</translation>
    </message>
    <message>
        <source>L:</source>
        <comment>ruler tool option</comment>
        <translation>길이:</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>올가미</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>다각형</translation>
    </message>
</context>
<context>
    <name>SelectionToolOptionsBox</name>
    <message>
        <source>H:</source>
        <translation>수평:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>수직:</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>연결</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>회전</translation>
    </message>
    <message>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>이동</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
</context>
<context>
    <name>ShiftTraceToolOptionBox</name>
    <message>
        <source>Reset Previous</source>
        <translation>리셋</translation>
    </message>
    <message>
        <source>Reset Following</source>
        <translation>뒤에 있는 리셋</translation>
    </message>
    <message>
        <source>Previous Drawing</source>
        <translation>이전 그림</translation>
    </message>
    <message>
        <source>Following Drawing</source>
        <translation>그림 다음의 컷</translation>
    </message>
</context>
<context>
    <name>SkeletonTool</name>
    <message>
        <source>Show Only Active Skeleton</source>
        <translation>활성 골격만 표시</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>글로벌 키</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>모드:</translation>
    </message>
    <message>
        <source>Build Skeleton</source>
        <translation>골격 만들기</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>애니메이션</translation>
    </message>
    <message>
        <source>Inverse Kinematics</source>
        <translation>역 운동학</translation>
    </message>
    <message>
        <source>Reset Pinned Center</source>
        <translation>고정중심 리셋</translation>
    </message>
</context>
<context>
    <name>StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation type="vanished">현재</translation>
    </message>
</context>
<context>
    <name>StylePickerTool</name>
    <message>
        <source>No current level.</source>
        <translation>현재 레벨이 없음.</translation>
    </message>
    <message>
        <source>Current level has no available palette.</source>
        <translation>현재 레벨에 사용 가능한 팔레트가 없음.</translation>
    </message>
    <message>
        <source>Palette must have more than one palette to be organized.</source>
        <translation>팔레트는 둘 이상의 팔레트를 구성해야함.</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>모드:</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>영역</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>선 &amp; 영역</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>수동적 선택</translation>
    </message>
    <message>
        <source>Organize Palette</source>
        <translation>팔레트 정리</translation>
    </message>
</context>
<context>
    <name>StylePickerToolOptionsBox</name>
    <message>
        <source>With this option being activated, the picked style will be
moved to the end of the first page of the palette.</source>
        <translation>이 옵션이 활성화되면 선택한 스타일이 팔레트의 첫 페이지 끝으로 이동한다.</translation>
    </message>
</context>
<context>
    <name>ToonzRasterBrushTool</name>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>경도:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>부드러운:</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation>그리기 순서:</translation>
    </message>
    <message>
        <source>Over All</source>
        <translation>맨 위</translation>
    </message>
    <message>
        <source>Under All</source>
        <translation>맨 아래</translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation>팔레트 순서</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>사전설정:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;사용자 정의&gt;</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>연필</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>압력</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>잠금 알파</translation>
    </message>
</context>
<context>
    <name>ToonzVectorBrushTool</name>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>정확도:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>부드러운:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>사전설정:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;사용자 정의&gt;</translation>
    </message>
    <message>
        <source>Break</source>
        <translation>분리</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>압력</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>캡</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>결합</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>마이터:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>범위:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>스냅</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>끄기</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation>선형</translation>
    </message>
    <message>
        <source>In</source>
        <translation>가속</translation>
    </message>
    <message>
        <source>Out</source>
        <translation>감속</translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation>가속&amp;감속</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>낮은</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>중간</translation>
    </message>
    <message>
        <source>High</source>
        <translation>높은</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>버트 캡</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>라운드 캡</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>돌출선 끝</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>마이터 결합</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>라운드 결합</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>베벨 결합</translation>
    </message>
</context>
<context>
    <name>TrackerTool</name>
    <message>
        <source>Width:</source>
        <translation>폭:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>높이:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TypeTool</name>
    <message>
        <source>Font:</source>
        <translation>글꼴:</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>스타일:</translation>
    </message>
    <message>
        <source>Vertical Orientation</source>
        <translation>수직방향</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
</context>
<context>
    <name>VectorSelectionTool</name>
    <message>
        <source>Mode:</source>
        <translation>모드:</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Selected Frames</source>
        <translation>선택 프레임</translation>
    </message>
    <message>
        <source>Whole Level</source>
        <translation>전체레벨</translation>
    </message>
    <message>
        <source>Same Style</source>
        <translation>동일한 유형</translation>
    </message>
    <message>
        <source>Same Style on Selected Frames</source>
        <translation>선택한 프레임의 동일 유형</translation>
    </message>
    <message>
        <source>Same Style on Whole Level</source>
        <translation>동일한 스타일의 전체레벨</translation>
    </message>
    <message>
        <source>Boundary Strokes</source>
        <translation>경계선</translation>
    </message>
    <message>
        <source>Boundaries on Selected Frames</source>
        <translation>선택된 프레임 경계선</translation>
    </message>
    <message>
        <source>Boundaries on Whole Level</source>
        <translation>선택된 프레임 경계선</translation>
    </message>
    <message>
        <source>Preserve Thickness</source>
        <translation>두께 유지</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>캡</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>버트 캡</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>라운드 캡</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>돌출선 끝</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>결합</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>마이터 결합</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>라운드 결합</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>베벨 결합</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>마이터:</translation>
    </message>
    <message>
        <source>Include Intersection</source>
        <translation>인터페이스 포함</translation>
    </message>
</context>
<context>
    <name>VectorTapeTool</name>
    <message>
        <source>Smooth</source>
        <translation>부드러운</translation>
    </message>
    <message>
        <source>Join Vectors</source>
        <translation>백터 결합</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>모드:</translation>
    </message>
    <message>
        <source>Endpoint to Endpoint</source>
        <translation>끝점에서 끝점</translation>
    </message>
    <message>
        <source>Endpoint to Line</source>
        <translation>선에서 끝점</translation>
    </message>
    <message>
        <source>Line to Line</source>
        <translation>선에서 선</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>표준</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>직사각형</translation>
    </message>
</context>
<context>
    <name>ZoomToolOptionsBox</name>
    <message>
        <source>Reset Zoom</source>
        <translation>확대 축소 재설정</translation>
    </message>
</context>
</TS>
